@@ -1,5 +1,5 @@
 package YAPC::Russia;
-$YAPC::Russia::VERSION = '2.0.0';
+$YAPC::Russia::VERSION = '3.0.0';
 # ABSTRACT: Perl conference YAPC::Russia
 
 
@@ -73,6 +73,15 @@ sub _get_data_for_year {
                 foursquare => 'https://foursquare.com/v/mailru-hq/4b980acdf964a520532835e3',
             }
         },
+        2016 => {
+            dates => [qw(2016-06-25)],
+            place => {
+                city => 'Moscow',
+                name_ru => 'Mail.ru',
+                address_ru => 'Ленинградский проспект 39, стр. 79',
+                foursquare => 'https://foursquare.com/v/mailru-hq/4b980acdf964a520532835e3',
+            }
+        },
     );
 
     if (exists $data{$year}) {
@@ -96,7 +105,7 @@ YAPC::Russia - Perl conference YAPC::Russia
 
 =head1 VERSION
 
-version 2.0.0
+version 3.0.0
 
 =head1 DESCRIPTION
 
@@ -110,7 +119,7 @@ Please visit L<http://semver.org/> to find out all about this great thing.
 =head2 new
 
     my $yr = YAPC::Russia->new(
-        year => 2015,
+        year => 2016,
     );
 
 =head2 get_dates
@@ -119,10 +128,9 @@ Returns list of Class::Date objects with dates of the YAPC::Russia event.
 
     $yr->get_dates();
 
-For the year 2015 it will return objects with dates:
+For the year 2016 it will return objects with dates:
 
-    2015-05-16
-    2015-05-17
+    2016-06-25
 
 =head2 get_place
 
@@ -130,7 +138,7 @@ Returns hashref with data about place where YAPC::Russia is held.
 
     $yr->get_place();
 
-For the year 2015 it will return:
+For the year 2016 it will return:
 
     {
         city => 'Moscow',
